CollectionsInternalClient class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ClientCall<Q, R>
-
inherited
-
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ResponseStream<R>
-
inherited
-
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options})
→ ResponseFuture<R>
-
inherited
-
get(GetCollectionInfoRequestInternal request, {CallOptions? options})
→ ResponseFuture<GetCollectionInfoResponse>
-
-
getShardRecoveryPoint(GetShardRecoveryPointRequest request, {CallOptions? options})
→ ResponseFuture<GetShardRecoveryPointResponse>
-
-
initiate(InitiateShardTransferRequest request, {CallOptions? options})
→ ResponseFuture<CollectionOperationResponse>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateShardCutoffPoint(UpdateShardCutoffPointRequest request, {CallOptions? options})
→ ResponseFuture<CollectionOperationResponse>
-
-
waitForShardState(WaitForShardStateRequest request, {CallOptions? options})
→ ResponseFuture<CollectionOperationResponse>
-