hnswEf property
Params relevant to HNSW index. Size of the beam in a beam-search. Larger the value - more accurate the result, more time required for search.
Implementation
@$pb.TagNumber(1)
$fixnum.Int64 get hnswEf => $_getI64(0);
Params relevant to HNSW index. Size of the beam in a beam-search. Larger the value - more accurate the result, more time required for search.
@$pb.TagNumber(1)
$fixnum.Int64 get hnswEf => $_getI64(0);