RecommendStrategy class

How to use positive and negative vectors to find the results, default is AverageVector.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) RecommendStrategy?

Constants

AverageVector → const RecommendStrategy
Average positive and negative vectors and create a single query with the formula query = avg_pos + avg_pos - avg_neg. Then performs normal search.
BestScore → const RecommendStrategy
Uses custom search objective. Each candidate is compared against all examples, its score is then chosen from the max(max_pos_score, max_neg_score). If the max_neg_score is chosen then it is squared and negated.
SumScores → const RecommendStrategy
Uses custom search objective. Compares against all inputs, sums all the scores. Scores against positive vectors are added, against negatives are subtracted.
values → const List<RecommendStrategy>