QdrantInternalServiceBase class abstract

Inheritance
Annotations

Constructors

QdrantInternalServiceBase()

Properties

$name String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getConsensusCommit(ServiceCall call, GetConsensusCommitRequest request) Future<GetConsensusCommitResponse>
getConsensusCommit_Pre(ServiceCall $call, Future<GetConsensusCommitRequest> $request) Future<GetConsensusCommitResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
waitOnConsensusCommit(ServiceCall call, WaitOnConsensusCommitRequest request) Future<WaitOnConsensusCommitResponse>
waitOnConsensusCommit_Pre(ServiceCall $call, Future<WaitOnConsensusCommitRequest> $request) Future<WaitOnConsensusCommitResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited