RaftServiceBase class abstract

Inheritance
Annotations

Constructors

RaftServiceBase()

Properties

$name String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
addPeerAsParticipant(ServiceCall call, PeerId request) Future<Empty>
addPeerAsParticipant_Pre(ServiceCall $call, Future<PeerId> $request) Future<Empty>
addPeerToKnown(ServiceCall call, AddPeerToKnownMessage request) Future<AllPeers>
addPeerToKnown_Pre(ServiceCall $call, Future<AddPeerToKnownMessage> $request) Future<AllPeers>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(ServiceCall call, RaftMessage request) Future<Empty>
send_Pre(ServiceCall $call, Future<RaftMessage> $request) Future<Empty>
toString() String
A string representation of this object.
inherited
whoIs(ServiceCall call, PeerId request) Future<Uri>
whoIs_Pre(ServiceCall $call, Future<PeerId> $request) Future<Uri>

Operators

operator ==(Object other) bool
The equality operator.
inherited