ShardSnapshotsClient class

Inheritance
Annotations

Constructors

ShardSnapshotsClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) ResponseFuture<R>
inherited
create(CreateShardSnapshotRequest request, {CallOptions? options}) ResponseFuture<CreateSnapshotResponse>
delete(DeleteShardSnapshotRequest request, {CallOptions? options}) ResponseFuture<DeleteSnapshotResponse>
list(ListShardSnapshotsRequest request, {CallOptions? options}) ResponseFuture<ListSnapshotsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recover(RecoverShardSnapshotRequest request, {CallOptions? options}) ResponseFuture<RecoverSnapshotResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited