ShardSnapshotsServiceBase class abstract

Inheritance
Annotations

Constructors

ShardSnapshotsServiceBase()

Properties

$name String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
create(ServiceCall call, CreateShardSnapshotRequest request) Future<CreateSnapshotResponse>
create_Pre(ServiceCall $call, Future<CreateShardSnapshotRequest> $request) Future<CreateSnapshotResponse>
delete(ServiceCall call, DeleteShardSnapshotRequest request) Future<DeleteSnapshotResponse>
delete_Pre(ServiceCall $call, Future<DeleteShardSnapshotRequest> $request) Future<DeleteSnapshotResponse>
list(ServiceCall call, ListShardSnapshotsRequest request) Future<ListSnapshotsResponse>
list_Pre(ServiceCall $call, Future<ListShardSnapshotsRequest> $request) Future<ListSnapshotsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recover(ServiceCall call, RecoverShardSnapshotRequest request) Future<RecoverSnapshotResponse>
recover_Pre(ServiceCall $call, Future<RecoverShardSnapshotRequest> $request) Future<RecoverSnapshotResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited