indexedOnly property
If enabled, the engine will only perform search among indexed or small segments. Using this option prevents slow searches in case of delayed index, but does not guarantee that all uploaded vectors will be included in search results
Implementation
@$pb.TagNumber(4)
$core.bool get indexedOnly => $_getBF(3);