Properties
-
$name
→ String
-
no setteroverride
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
create(ServiceCall call, CreateSnapshotRequest request)
→ Future<CreateSnapshotResponse>
-
-
create_Pre(ServiceCall $call, Future<CreateSnapshotRequest> $request)
→ Future<CreateSnapshotResponse>
-
-
createFull(ServiceCall call, CreateFullSnapshotRequest request)
→ Future<CreateSnapshotResponse>
-
-
createFull_Pre(ServiceCall $call, Future<CreateFullSnapshotRequest> $request)
→ Future<CreateSnapshotResponse>
-
-
delete(ServiceCall call, DeleteSnapshotRequest request)
→ Future<DeleteSnapshotResponse>
-
-
delete_Pre(ServiceCall $call, Future<DeleteSnapshotRequest> $request)
→ Future<DeleteSnapshotResponse>
-
-
deleteFull(ServiceCall call, DeleteFullSnapshotRequest request)
→ Future<DeleteSnapshotResponse>
-
-
deleteFull_Pre(ServiceCall $call, Future<DeleteFullSnapshotRequest> $request)
→ Future<DeleteSnapshotResponse>
-
-
list(ServiceCall call, ListSnapshotsRequest request)
→ Future<ListSnapshotsResponse>
-
-
list_Pre(ServiceCall $call, Future<ListSnapshotsRequest> $request)
→ Future<ListSnapshotsResponse>
-
-
listFull(ServiceCall call, ListFullSnapshotsRequest request)
→ Future<ListSnapshotsResponse>
-
-
listFull_Pre(ServiceCall $call, Future<ListFullSnapshotsRequest> $request)
→ Future<ListSnapshotsResponse>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited